import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Shapes

import Check
import Core
import I18n

ColumnLayout {
    id: root
    objectName: "controls"

    spacing: 40

    property alias kbdInput: kbdInput
    property alias inputField: inputField
    property alias buttonsLayout: buttonsLayout
    property alias okButton: okButton
    property alias cancelButton: cancelButton

    // параметры
    property bool useDigits: true
    property string inputFieldClass: "inputField"
    property var okButtonTr: null
    property var cancelButtonTr: null

    // инициализация параметров
    function initParams(listParams) {
        root.useDigits = listParams.useDigits ? true : (listParams.useDigits === false ? false : true)
        root.inputFieldClass = listParams.inputFieldClass ? listParams.inputFieldClass : "inputField"
        root.okButtonTr = listParams.okButtonTr ? listParams.okButtonTr : null
        root.cancelButtonTr = listParams.cancelButtonTr ? listParams.cancelButtonTr : null
    }

    ColumnLayout {
        id: kbdInput
        objectName: "kbdInput"

        SGroupBox {
            id: inputFieldGroupBox
            Style.class: root.inputFieldClass

            contentItem: FocusScope {
                focus: true
                implicitHeight: inputField.implicitHeight

                STextEdit {
                    id: inputField
                    anchors.fill: parent
                    objectName: "inputField"

                    inputMethodHints: root.useDigits ? Qt.ImhDigitsOnly : 0
                    echoMode: TextInput.Normal
                    focus: true
                    clip: true

                    Component.onCompleted: () => this.forceActiveFocus()
                }
            }

            Layout.fillWidth: true
        }

        InlineKeyboard {
            Layout.fillWidth: true
            Layout.preferredHeight: 350
            layoutType: root.useDigits ? "digits" : "main"
        }

        spacing: 40
    }

    ColumnLayout {
        id: buttonsLayout

        spacing: 15
        Layout.fillWidth: true

        ActionButton {
            id: okButton
            objectName: "okButton"

            Tr { code: root.okButtonTr; tr: root.okButtonTr; fallback: "inputOk" }

            Layout.fillWidth: true
            Layout.preferredHeight: 105
        }

        ActionButton {
            id: cancelButton
            objectName: "cancelButton"
            Style.class: "outlined"
            icon: Style.parameter("icon.input.cancel")

            property Tr cancelButtonTr

            Tr { code: root.cancelButtonTr; tr: root.cancelButtonTr; fallback: "inputCancel" }

            Layout.fillWidth: true
            Layout.preferredHeight: 105
        }
    }

    Layout.fillWidth: true
    Layout.fillHeight: true
}

